
# Job Search Tool
> A job search tool that will help the users find a job that suit their skills. 

![GitHub version](https://badge.fury.io/gh/rodrez%2FJobs-and-Skills.svg)
![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

----------
## Table of Contents
- [Installation](#Installation)
- [Features](#Features)
- [Contributing](#Contributing)
- [FAQ](#FAQ)
- [Support](#Support)
----------
## Code Example
    start_time = datetime.datetime.now()
    print("Collecting jobs...")
    start_search(job, location)
    
    print("Removing duplicates")
    remove_duplicate("panda_job_data.csv")
    
    print("Converting data...")
    csv_to_md("panda_job_data.csv", "tech jobs")
    
    print("Job collection completed")
    end_time = datetime.datetime.now()
    print(f"Time elapsed: {end_time - start_time}")
----------
## Installation
- All the `code` required to get started
- Images of what it should look like

**Clone**

- Clone this repo to your local machine using `https://github.com/rodrez/Jobs-and-Skills`

**Requirements**

- In order to run the Job Tool we need the following libraries:
> install request first

    `pip install requests`
    
> now install BeautifulSoup4 

    `pip install beautifulsoup4`
    
> install request pandas

    `pip install pandas`
----------
## Features
- Work in progress
## Usage 
- Work in progress
## Documentation 
- Work in progress
----------
## Contributing
> To get started...

**Step 1**

- **Option 1**
    - 🍴 Fork this repo!
- **Option 2**
    - 👯 Clone this repo to your local machine using `https://github.com/rodrez/Jobs-and-Skills.git`

**Step 2**

- **HACK AWAY!** 🔨🔨🔨

**Step 3**

- 🔃 Create a new pull request using `[https://github.com/rodrez/Jobs-and-Skills/compare/](https://github.com/rodrez/Jobs-and-Skills/compare/)`.
----------

## FAQ
- **Work in Progress.**
    - No problem! Just do this.
----------
## Support

Reach out to me at one of the following places!

- Website at [rodrez.com](http://www.rodrez.com)
- Twitter at [@Rodrez_](http://twitter.com/rodrez_)
- Email at [fabian.rodrez@gmail.com](mailto:fabian.rodrez@gmail.com)
----------


- Copyright 2020 © Rodrez.
